pub struct ConfiguratePayload {Show 13 fields
pub file_name: Option<String>,
pub base_dir: Option<BaseDirectory>,
pub options: Option<PathOptions>,
pub provider: Option<ProviderPayload>,
pub schema_columns: Vec<SqliteColumn>,
pub data: Option<Value>,
pub keyring_entries: Option<Vec<KeyringEntry>>,
pub keyring_options: Option<KeyringOptions>,
pub keyring_delete_ids: Vec<String>,
pub with_unlock: bool,
pub return_data: Option<bool>,
pub create_if_missing: bool,
pub backup: bool,
}Expand description
Unified payload sent from TypeScript side for create/load/save/delete.
Fields
file_name: Option<String>base_dir: Option<BaseDirectory>options: Option<PathOptions>provider: Option<ProviderPayload>schema_columns: Vec<SqliteColumn>data: Option<Value>keyring_entries: Option<Vec<KeyringEntry>>keyring_options: Option<KeyringOptions>keyring_delete_ids: Vec<String>with_unlock: boolreturn_data: Option<bool>Whether create/save should return the resulting config data. Defaults to true for backward compatibility.
create_if_missing: boolWhen true, patch creates the config with the patch data if it does
not yet exist instead of returning an error.
backup: boolWhen true, rolling backup files are created before each write. Defaults to false (opt-in).
Implementations
Sourceimpl ConfiguratePayload
impl ConfiguratePayload
pub fn normalize(self) -> Result<NormalizedConfiguratePayload>