pub struct NormalizedConfiguratePayload {Show 14 fields
pub file_name: String,
pub base_dir: BaseDirectory,
pub dir_name: Option<String>,
pub current_path: Option<String>,
pub provider: NormalizedProvider,
pub schema_columns: Vec<SqliteColumn>,
pub data: Option<Value>,
pub keyring_entries: Option<Vec<KeyringEntry>>,
pub keyring_options: Option<KeyringOptions>,
pub keyring_delete_ids: Vec<String>,
pub with_unlock: bool,
pub return_data: bool,
pub create_if_missing: bool,
pub backup: bool,
}Expand description
Normalized payload used internally across all commands.
Fields
file_name: Stringbase_dir: BaseDirectorydir_name: Option<String>current_path: Option<String>provider: NormalizedProviderschema_columns: Vec<SqliteColumn>data: Option<Value>keyring_entries: Option<Vec<KeyringEntry>>keyring_options: Option<KeyringOptions>keyring_delete_ids: Vec<String>with_unlock: boolreturn_data: boolcreate_if_missing: boolWhen true, patch creates the config if it does not exist.
backup: boolWhen true, rolling backup files are created before each write.